@@ -1,7 +1,7 @@
 import logging
 
-from jsm_user_services.support.django_utils import get_from_settings_or_raise_missing_config
 from jsm_user_services.support.http_utils import request
+from jsm_user_services.support.settings_utils import get_from_settings_or_raise_missing_config
 
 logger = logging.getLogger(__name__)
 
@@ -17,14 +17,16 @@ def perform_recaptcha_validation(g_recaptcha_response: str) -> bool:
     )
     google_recaptcha_secret_key = get_from_settings_or_raise_missing_config("GOOGLE_RECAPTCHA_SECRET_KEY")
 
-    logger.debug("Performing request to Google to check if recaptcha is valid")
+    logger.info("Checking GoogleRecaptcha")
 
     data = {"response": g_recaptcha_response, "secret": google_recaptcha_secret_key}
 
     with request() as r:
         resp = r.post(google_recaptcha_url, data=data)
+    
     result_json = resp.json()
 
-    logger.debug(f"Status code: {resp.status_code}; body: {result_json}")
+    if not result_json.get("success"):
+        logger.info(f"GoogleRecaptcha failed! Input: {g_recaptcha_response} Output: {result_json}")
 
     return result_json.get("success")
